smartcard.Exceptions.NoCardException

# ``smartcard`.`Exceptions`.`NoCardException``

exception documentation

`class NoCardException(SmartcardException):`

View In Hierarchy

Raised when no card in is present in reader.

Method | `__init__` | Undocumented

Inherited from `SmartcardException`:

Method | `__str__` | Undocumented
Instance Variable | `hresult` | Undocumented

def __init__(self, message, hresult):
overrides `smartcard.Exceptions.SmartcardException.__init__`

Undocumented